Documentation
¶
Index ¶
- Variables
- type Condition
- func (*Condition) Descriptor() ([]byte, []int)
- func (this *Condition) Equal(that interface{}) bool
- func (m *Condition) GetLastUpdatedTimestamp() int64
- func (m *Condition) GetMessage() string
- func (m *Condition) GetMetadata() *types.Any
- func (m *Condition) GetObservedGeneration() int64
- func (m *Condition) GetReason() string
- func (m *Condition) GetStatus() ConditionStatus
- func (m *Condition) GetType() string
- func (this *Condition) GoString() string
- func (m *Condition) Marshal() (dAtA []byte, err error)
- func (m *Condition) MarshalTo(dAtA []byte) (int, error)
- func (m *Condition) MarshalToSizedBuffer(dAtA []byte) (int, error)
- func (*Condition) ProtoMessage()
- func (m *Condition) Reset()
- func (m *Condition) Size() (n int)
- func (this *Condition) String() string
- func (m *Condition) Unmarshal(dAtA []byte) error
- func (m *Condition) XXX_DiscardUnknown()
- func (m *Condition) XXX_Marshal(b []byte, deterministic bool) ([]byte, error)
- func (m *Condition) XXX_Merge(src proto.Message)
- func (m *Condition) XXX_Size() int
- func (m *Condition) XXX_Unmarshal(b []byte) error
- type ConditionStatus
- type Criterion
- func (*Criterion) Descriptor() ([]byte, []int)
- func (this *Criterion) Equal(that interface{}) bool
- func (m *Criterion) GetFieldName() string
- func (m *Criterion) GetMatchValue() *types.Any
- func (m *Criterion) GetOperator() CriterionOperator
- func (this *Criterion) GoString() string
- func (m *Criterion) Marshal() (dAtA []byte, err error)
- func (m *Criterion) MarshalTo(dAtA []byte) (int, error)
- func (m *Criterion) MarshalToSizedBuffer(dAtA []byte) (int, error)
- func (*Criterion) ProtoMessage()
- func (m *Criterion) Reset()
- func (m *Criterion) Size() (n int)
- func (this *Criterion) String() string
- func (m *Criterion) Unmarshal(dAtA []byte) error
- func (m *Criterion) XXX_DiscardUnknown()
- func (m *Criterion) XXX_Marshal(b []byte, deterministic bool) ([]byte, error)
- func (m *Criterion) XXX_Merge(src proto.Message)
- func (m *Criterion) XXX_Size() int
- func (m *Criterion) XXX_Unmarshal(b []byte) error
- type CriterionOperation
- func (*CriterionOperation) Descriptor() ([]byte, []int)
- func (this *CriterionOperation) Equal(that interface{}) bool
- func (m *CriterionOperation) GetCriterion() []*Criterion
- func (m *CriterionOperation) GetLogicalOperator() LogicalOperator
- func (m *CriterionOperation) GetSubOperations() []*CriterionOperation
- func (this *CriterionOperation) GoString() string
- func (m *CriterionOperation) Marshal() (dAtA []byte, err error)
- func (m *CriterionOperation) MarshalTo(dAtA []byte) (int, error)
- func (m *CriterionOperation) MarshalToSizedBuffer(dAtA []byte) (int, error)
- func (*CriterionOperation) ProtoMessage()
- func (m *CriterionOperation) Reset()
- func (m *CriterionOperation) Size() (n int)
- func (this *CriterionOperation) String() string
- func (m *CriterionOperation) Unmarshal(dAtA []byte) error
- func (m *CriterionOperation) XXX_DiscardUnknown()
- func (m *CriterionOperation) XXX_Marshal(b []byte, deterministic bool) ([]byte, error)
- func (m *CriterionOperation) XXX_Merge(src proto.Message)
- func (m *CriterionOperation) XXX_Size() int
- func (m *CriterionOperation) XXX_Unmarshal(b []byte) error
- type CriterionOperator
- type GroupInfo
- func (*GroupInfo) Descriptor() ([]byte, []int)
- func (this *GroupInfo) Equal(that interface{}) bool
- func (m *GroupInfo) GetHubVersion() string
- func (m *GroupInfo) GetName() string
- func (m *GroupInfo) GetVersion() string
- func (this *GroupInfo) GoString() string
- func (m *GroupInfo) Marshal() (dAtA []byte, err error)
- func (m *GroupInfo) MarshalTo(dAtA []byte) (int, error)
- func (m *GroupInfo) MarshalToSizedBuffer(dAtA []byte) (int, error)
- func (*GroupInfo) ProtoMessage()
- func (m *GroupInfo) Reset()
- func (m *GroupInfo) Size() (n int)
- func (this *GroupInfo) String() string
- func (m *GroupInfo) Unmarshal(dAtA []byte) error
- func (m *GroupInfo) XXX_DiscardUnknown()
- func (m *GroupInfo) XXX_Marshal(b []byte, deterministic bool) ([]byte, error)
- func (m *GroupInfo) XXX_Merge(src proto.Message)
- func (m *GroupInfo) XXX_Size() int
- func (m *GroupInfo) XXX_Unmarshal(b []byte) error
- type IndexDescriptor
- func (*IndexDescriptor) Descriptor() ([]byte, []int)
- func (this *IndexDescriptor) Equal(that interface{}) bool
- func (m *IndexDescriptor) GetKey() string
- func (m *IndexDescriptor) GetPath() string
- func (m *IndexDescriptor) GetTypeOverride() string
- func (this *IndexDescriptor) GoString() string
- func (m *IndexDescriptor) Marshal() (dAtA []byte, err error)
- func (m *IndexDescriptor) MarshalTo(dAtA []byte) (int, error)
- func (m *IndexDescriptor) MarshalToSizedBuffer(dAtA []byte) (int, error)
- func (*IndexDescriptor) ProtoMessage()
- func (m *IndexDescriptor) Reset()
- func (m *IndexDescriptor) Size() (n int)
- func (this *IndexDescriptor) String() string
- func (m *IndexDescriptor) Unmarshal(dAtA []byte) error
- func (m *IndexDescriptor) XXX_DiscardUnknown()
- func (m *IndexDescriptor) XXX_Marshal(b []byte, deterministic bool) ([]byte, error)
- func (m *IndexDescriptor) XXX_Merge(src proto.Message)
- func (m *IndexDescriptor) XXX_Size() int
- func (m *IndexDescriptor) XXX_Unmarshal(b []byte) error
- type ListOptionsExt
- func (*ListOptionsExt) Descriptor() ([]byte, []int)
- func (this *ListOptionsExt) Equal(that interface{}) bool
- func (m *ListOptionsExt) GetOperation() *CriterionOperation
- func (m *ListOptionsExt) GetOrderBy() []*OrderBy
- func (m *ListOptionsExt) GetPagination() *PaginationSpec
- func (m *ListOptionsExt) GetReturnedFieldSkipList() []string
- func (this *ListOptionsExt) GoString() string
- func (m *ListOptionsExt) Marshal() (dAtA []byte, err error)
- func (m *ListOptionsExt) MarshalTo(dAtA []byte) (int, error)
- func (m *ListOptionsExt) MarshalToSizedBuffer(dAtA []byte) (int, error)
- func (*ListOptionsExt) ProtoMessage()
- func (m *ListOptionsExt) Reset()
- func (m *ListOptionsExt) Size() (n int)
- func (this *ListOptionsExt) String() string
- func (m *ListOptionsExt) Unmarshal(dAtA []byte) error
- func (m *ListOptionsExt) XXX_DiscardUnknown()
- func (m *ListOptionsExt) XXX_Marshal(b []byte, deterministic bool) ([]byte, error)
- func (m *ListOptionsExt) XXX_Merge(src proto.Message)
- func (m *ListOptionsExt) XXX_Size() int
- func (m *ListOptionsExt) XXX_Unmarshal(b []byte) error
- type LogicalOperator
- type OrderBy
- func (*OrderBy) Descriptor() ([]byte, []int)
- func (this *OrderBy) Equal(that interface{}) bool
- func (m *OrderBy) GetDir() SortOrder
- func (m *OrderBy) GetField() string
- func (this *OrderBy) GoString() string
- func (m *OrderBy) Marshal() (dAtA []byte, err error)
- func (m *OrderBy) MarshalTo(dAtA []byte) (int, error)
- func (m *OrderBy) MarshalToSizedBuffer(dAtA []byte) (int, error)
- func (*OrderBy) ProtoMessage()
- func (m *OrderBy) Reset()
- func (m *OrderBy) Size() (n int)
- func (this *OrderBy) String() string
- func (m *OrderBy) Unmarshal(dAtA []byte) error
- func (m *OrderBy) XXX_DiscardUnknown()
- func (m *OrderBy) XXX_Marshal(b []byte, deterministic bool) ([]byte, error)
- func (m *OrderBy) XXX_Merge(src proto.Message)
- func (m *OrderBy) XXX_Size() int
- func (m *OrderBy) XXX_Unmarshal(b []byte) error
- type PaginationSpec
- func (*PaginationSpec) Descriptor() ([]byte, []int)
- func (this *PaginationSpec) Equal(that interface{}) bool
- func (m *PaginationSpec) GetLimit() int32
- func (m *PaginationSpec) GetOffset() int32
- func (this *PaginationSpec) GoString() string
- func (m *PaginationSpec) Marshal() (dAtA []byte, err error)
- func (m *PaginationSpec) MarshalTo(dAtA []byte) (int, error)
- func (m *PaginationSpec) MarshalToSizedBuffer(dAtA []byte) (int, error)
- func (*PaginationSpec) ProtoMessage()
- func (m *PaginationSpec) Reset()
- func (m *PaginationSpec) Size() (n int)
- func (this *PaginationSpec) String() string
- func (m *PaginationSpec) Unmarshal(dAtA []byte) error
- func (m *PaginationSpec) XXX_DiscardUnknown()
- func (m *PaginationSpec) XXX_Marshal(b []byte, deterministic bool) ([]byte, error)
- func (m *PaginationSpec) XXX_Merge(src proto.Message)
- func (m *PaginationSpec) XXX_Size() int
- func (m *PaginationSpec) XXX_Unmarshal(b []byte) error
- type RelationshipDescriptor
- func (*RelationshipDescriptor) Descriptor() ([]byte, []int)
- func (this *RelationshipDescriptor) Equal(that interface{}) bool
- func (m *RelationshipDescriptor) GetPath() string
- func (this *RelationshipDescriptor) GoString() string
- func (m *RelationshipDescriptor) Marshal() (dAtA []byte, err error)
- func (m *RelationshipDescriptor) MarshalTo(dAtA []byte) (int, error)
- func (m *RelationshipDescriptor) MarshalToSizedBuffer(dAtA []byte) (int, error)
- func (*RelationshipDescriptor) ProtoMessage()
- func (m *RelationshipDescriptor) Reset()
- func (m *RelationshipDescriptor) Size() (n int)
- func (this *RelationshipDescriptor) String() string
- func (m *RelationshipDescriptor) Unmarshal(dAtA []byte) error
- func (m *RelationshipDescriptor) XXX_DiscardUnknown()
- func (m *RelationshipDescriptor) XXX_Marshal(b []byte, deterministic bool) ([]byte, error)
- func (m *RelationshipDescriptor) XXX_Merge(src proto.Message)
- func (m *RelationshipDescriptor) XXX_Size() int
- func (m *RelationshipDescriptor) XXX_Unmarshal(b []byte) error
- type ResourceDescriptor
- func (*ResourceDescriptor) Descriptor() ([]byte, []int)
- func (this *ResourceDescriptor) Equal(that interface{}) bool
- func (m *ResourceDescriptor) GetCategories() []string
- func (m *ResourceDescriptor) GetConversion() bool
- func (m *ResourceDescriptor) GetImmutable() bool
- func (m *ResourceDescriptor) GetName() string
- func (m *ResourceDescriptor) GetScope() string
- func (m *ResourceDescriptor) GetShortNames() []string
- func (m *ResourceDescriptor) GetSingular() string
- func (this *ResourceDescriptor) GoString() string
- func (m *ResourceDescriptor) Marshal() (dAtA []byte, err error)
- func (m *ResourceDescriptor) MarshalTo(dAtA []byte) (int, error)
- func (m *ResourceDescriptor) MarshalToSizedBuffer(dAtA []byte) (int, error)
- func (*ResourceDescriptor) ProtoMessage()
- func (m *ResourceDescriptor) Reset()
- func (m *ResourceDescriptor) Size() (n int)
- func (this *ResourceDescriptor) String() string
- func (m *ResourceDescriptor) Unmarshal(dAtA []byte) error
- func (m *ResourceDescriptor) XXX_DiscardUnknown()
- func (m *ResourceDescriptor) XXX_Marshal(b []byte, deterministic bool) ([]byte, error)
- func (m *ResourceDescriptor) XXX_Merge(src proto.Message)
- func (m *ResourceDescriptor) XXX_Size() int
- func (m *ResourceDescriptor) XXX_Unmarshal(b []byte) error
- type ResourceIdentifier
- func (*ResourceIdentifier) Descriptor() ([]byte, []int)
- func (this *ResourceIdentifier) Equal(that interface{}) bool
- func (m *ResourceIdentifier) GetName() string
- func (m *ResourceIdentifier) GetNamespace() string
- func (this *ResourceIdentifier) GoString() string
- func (m *ResourceIdentifier) Marshal() (dAtA []byte, err error)
- func (m *ResourceIdentifier) MarshalTo(dAtA []byte) (int, error)
- func (m *ResourceIdentifier) MarshalToSizedBuffer(dAtA []byte) (int, error)
- func (*ResourceIdentifier) ProtoMessage()
- func (m *ResourceIdentifier) Reset()
- func (m *ResourceIdentifier) Size() (n int)
- func (this *ResourceIdentifier) String() string
- func (m *ResourceIdentifier) Unmarshal(dAtA []byte) error
- func (m *ResourceIdentifier) XXX_DiscardUnknown()
- func (m *ResourceIdentifier) XXX_Marshal(b []byte, deterministic bool) ([]byte, error)
- func (m *ResourceIdentifier) XXX_Merge(src proto.Message)
- func (m *ResourceIdentifier) XXX_Size() int
- func (m *ResourceIdentifier) XXX_Unmarshal(b []byte) error
- type ResourceListDescriptor
- func (*ResourceListDescriptor) Descriptor() ([]byte, []int)
- func (this *ResourceListDescriptor) Equal(that interface{}) bool
- func (this *ResourceListDescriptor) GoString() string
- func (m *ResourceListDescriptor) Marshal() (dAtA []byte, err error)
- func (m *ResourceListDescriptor) MarshalTo(dAtA []byte) (int, error)
- func (m *ResourceListDescriptor) MarshalToSizedBuffer(dAtA []byte) (int, error)
- func (*ResourceListDescriptor) ProtoMessage()
- func (m *ResourceListDescriptor) Reset()
- func (m *ResourceListDescriptor) Size() (n int)
- func (this *ResourceListDescriptor) String() string
- func (m *ResourceListDescriptor) Unmarshal(dAtA []byte) error
- func (m *ResourceListDescriptor) XXX_DiscardUnknown()
- func (m *ResourceListDescriptor) XXX_Marshal(b []byte, deterministic bool) ([]byte, error)
- func (m *ResourceListDescriptor) XXX_Merge(src proto.Message)
- func (m *ResourceListDescriptor) XXX_Size() int
- func (m *ResourceListDescriptor) XXX_Unmarshal(b []byte) error
- type ResourceReference
- func (*ResourceReference) Descriptor() ([]byte, []int)
- func (this *ResourceReference) Equal(that interface{}) bool
- func (m *ResourceReference) GetType() string
- func (this *ResourceReference) GoString() string
- func (m *ResourceReference) Marshal() (dAtA []byte, err error)
- func (m *ResourceReference) MarshalTo(dAtA []byte) (int, error)
- func (m *ResourceReference) MarshalToSizedBuffer(dAtA []byte) (int, error)
- func (*ResourceReference) ProtoMessage()
- func (m *ResourceReference) Reset()
- func (m *ResourceReference) Size() (n int)
- func (this *ResourceReference) String() string
- func (m *ResourceReference) Unmarshal(dAtA []byte) error
- func (m *ResourceReference) XXX_DiscardUnknown()
- func (m *ResourceReference) XXX_Marshal(b []byte, deterministic bool) ([]byte, error)
- func (m *ResourceReference) XXX_Merge(src proto.Message)
- func (m *ResourceReference) XXX_Size() int
- func (m *ResourceReference) XXX_Unmarshal(b []byte) error
- type SortOrder
- type TypedStruct
- func (*TypedStruct) Descriptor() ([]byte, []int)
- func (this *TypedStruct) Equal(that interface{}) bool
- func (m *TypedStruct) GetTypeUrl() string
- func (m *TypedStruct) GetValue() *types.Struct
- func (this *TypedStruct) GoString() string
- func (m *TypedStruct) Marshal() (dAtA []byte, err error)
- func (m *TypedStruct) MarshalTo(dAtA []byte) (int, error)
- func (m *TypedStruct) MarshalToSizedBuffer(dAtA []byte) (int, error)
- func (*TypedStruct) ProtoMessage()
- func (m *TypedStruct) Reset()
- func (m *TypedStruct) Size() (n int)
- func (this *TypedStruct) String() string
- func (m *TypedStruct) Unmarshal(dAtA []byte) error
- func (m *TypedStruct) XXX_DiscardUnknown()
- func (m *TypedStruct) XXX_Marshal(b []byte, deterministic bool) ([]byte, error)
- func (m *TypedStruct) XXX_Merge(src proto.Message)
- func (m *TypedStruct) XXX_Size() int
- func (m *TypedStruct) XXX_Unmarshal(b []byte) error
- type Validation
- func (*Validation) Descriptor() ([]byte, []int)
- func (this *Validation) Equal(that interface{}) bool
- func (m *Validation) GetEmail() bool
- func (m *Validation) GetExclMax() bool
- func (m *Validation) GetExclMin() bool
- func (m *Validation) GetHostAddress() bool
- func (m *Validation) GetHostname() bool
- func (m *Validation) GetIn() []string
- func (m *Validation) GetIp() bool
- func (m *Validation) GetIpv4() bool
- func (m *Validation) GetIpv6() bool
- func (m *Validation) GetItems() *Validation
- func (m *Validation) GetKeys() *Validation
- func (m *Validation) GetMax() string
- func (m *Validation) GetMaxItems() string
- func (m *Validation) GetMaxLength() string
- func (m *Validation) GetMin() string
- func (m *Validation) GetMinItems() string
- func (m *Validation) GetMinLength() string
- func (m *Validation) GetMsg() string
- func (m *Validation) GetNotIn() []string
- func (m *Validation) GetNotPattern() string
- func (m *Validation) GetOptional() bool
- func (m *Validation) GetOptionalRequired() isValidation_OptionalRequired
- func (m *Validation) GetPattern() string
- func (m *Validation) GetRequired() bool
- func (m *Validation) GetUniqueItems() bool
- func (m *Validation) GetUri() bool
- func (m *Validation) GetUuid() bool
- func (m *Validation) GetValues() *Validation
- func (this *Validation) GoString() string
- func (m *Validation) Marshal() (dAtA []byte, err error)
- func (m *Validation) MarshalTo(dAtA []byte) (int, error)
- func (m *Validation) MarshalToSizedBuffer(dAtA []byte) (int, error)
- func (*Validation) ProtoMessage()
- func (m *Validation) Reset()
- func (m *Validation) Size() (n int)
- func (this *Validation) String() string
- func (m *Validation) Unmarshal(dAtA []byte) error
- func (m *Validation) XXX_DiscardUnknown()
- func (m *Validation) XXX_Marshal(b []byte, deterministic bool) ([]byte, error)
- func (m *Validation) XXX_Merge(src proto.Message)
- func (*Validation) XXX_OneofWrappers() []interface{}
- func (m *Validation) XXX_Size() int
- func (m *Validation) XXX_Unmarshal(b []byte) error
- type Validation_Optional
- func (this *Validation_Optional) Equal(that interface{}) bool
- func (this *Validation_Optional) GoString() string
- func (m *Validation_Optional) MarshalTo(dAtA []byte) (int, error)
- func (m *Validation_Optional) MarshalToSizedBuffer(dAtA []byte) (int, error)
- func (m *Validation_Optional) Size() (n int)
- func (this *Validation_Optional) String() string
- type Validation_Required
- func (this *Validation_Required) Equal(that interface{}) bool
- func (this *Validation_Required) GoString() string
- func (m *Validation_Required) MarshalTo(dAtA []byte) (int, error)
- func (m *Validation_Required) MarshalToSizedBuffer(dAtA []byte) (int, error)
- func (m *Validation_Required) Size() (n int)
- func (this *Validation_Required) String() string
Constants ¶
This section is empty.
Variables ¶
var ( ErrInvalidLengthConditions = fmt.Errorf("proto: negative length found during unmarshaling") ErrIntOverflowConditions = fmt.Errorf("proto: integer overflow") ErrUnexpectedEndOfGroupConditions = fmt.Errorf("proto: unexpected end of group") )
var ( ErrInvalidLengthList = fmt.Errorf("proto: negative length found during unmarshaling") ErrIntOverflowList = fmt.Errorf("proto: integer overflow") ErrUnexpectedEndOfGroupList = fmt.Errorf("proto: unexpected end of group") )
var ( ErrInvalidLengthOptions = fmt.Errorf("proto: negative length found during unmarshaling") ErrIntOverflowOptions = fmt.Errorf("proto: integer overflow") ErrUnexpectedEndOfGroupOptions = fmt.Errorf("proto: unexpected end of group") )
var ( ErrInvalidLengthTypedStruct = fmt.Errorf("proto: negative length found during unmarshaling") ErrIntOverflowTypedStruct = fmt.Errorf("proto: integer overflow") ErrUnexpectedEndOfGroupTypedStruct = fmt.Errorf("proto: unexpected end of group") )
var ConditionStatus_name = map[int32]string{
0: "CONDITION_STATUS_UNKNOWN",
1: "CONDITION_STATUS_TRUE",
2: "CONDITION_STATUS_FALSE",
}
var ConditionStatus_value = map[string]int32{
"CONDITION_STATUS_UNKNOWN": 0,
"CONDITION_STATUS_TRUE": 1,
"CONDITION_STATUS_FALSE": 2,
}
var CriterionOperator_name = map[int32]string{
0: "CRITERION_OPERATOR_INVALID",
1: "CRITERION_OPERATOR_EQUAL",
2: "CRITERION_OPERATOR_NOT_EQUAL",
3: "CRITERION_OPERATOR_GREATER_THAN",
4: "CRITERION_OPERATOR_GREATER_THAN_OR_EQUAL_TO",
5: "CRITERION_OPERATOR_LESS_THAN",
6: "CRITERION_OPERATOR_LESS_THAN_OR_EQUAL_TO",
7: "CRITERION_OPERATOR_IN",
8: "CRITERION_OPERATOR_NOT_IN",
9: "CRITERION_OPERATOR_LIKE",
10: "CRITERION_OPERATOR_IS_NULL",
11: "CRITERION_OPERATOR_IS_NOT_NULL",
}
var CriterionOperator_value = map[string]int32{
"CRITERION_OPERATOR_INVALID": 0,
"CRITERION_OPERATOR_EQUAL": 1,
"CRITERION_OPERATOR_NOT_EQUAL": 2,
"CRITERION_OPERATOR_GREATER_THAN": 3,
"CRITERION_OPERATOR_GREATER_THAN_OR_EQUAL_TO": 4,
"CRITERION_OPERATOR_LESS_THAN": 5,
"CRITERION_OPERATOR_LESS_THAN_OR_EQUAL_TO": 6,
"CRITERION_OPERATOR_IN": 7,
"CRITERION_OPERATOR_NOT_IN": 8,
"CRITERION_OPERATOR_LIKE": 9,
"CRITERION_OPERATOR_IS_NULL": 10,
"CRITERION_OPERATOR_IS_NOT_NULL": 11,
}
var E_EnumRenameTo = &proto.ExtensionDesc{ ExtendedType: (*descriptor.EnumOptions)(nil), ExtensionType: (*string)(nil), Field: 7181, Name: "michelangelo.api.enum_rename_to", Tag: "bytes,7181,opt,name=enum_rename_to", Filename: "michelangelo/api/options.proto", }
var E_ExternalStorage = &proto.ExtensionDesc{ ExtendedType: (*descriptor.FieldOptions)(nil), ExtensionType: (*bool)(nil), Field: 5772, Name: "michelangelo.api.external_storage", Tag: "varint,5772,opt,name=external_storage", Filename: "michelangelo/api/options.proto", }
var E_FieldRenameTo = &proto.ExtensionDesc{ ExtendedType: (*descriptor.FieldOptions)(nil), ExtensionType: (*string)(nil), Field: 5775, Name: "michelangelo.api.field_rename_to", Tag: "bytes,5775,opt,name=field_rename_to", Filename: "michelangelo/api/options.proto", }
var E_GroupInfo = &proto.ExtensionDesc{ ExtendedType: (*descriptor.FileOptions)(nil), ExtensionType: (*GroupInfo)(nil), Field: 5730, Name: "michelangelo.api.group_info", Tag: "bytes,5730,opt,name=group_info", Filename: "michelangelo/api/options.proto", }
var E_IgnoreUnmapped = &proto.ExtensionDesc{ ExtendedType: (*descriptor.FieldOptions)(nil), ExtensionType: (*bool)(nil), Field: 5774, Name: "michelangelo.api.ignore_unmapped", Tag: "varint,5774,opt,name=ignore_unmapped", Filename: "michelangelo/api/options.proto", }
var E_IgnoreUnmappedHubFields = &proto.ExtensionDesc{ ExtendedType: (*descriptor.MessageOptions)(nil), ExtensionType: ([]string)(nil), Field: 1061, Name: "michelangelo.api.ignore_unmapped_hub_fields", Tag: "bytes,1061,rep,name=ignore_unmapped_hub_fields", Filename: "michelangelo/api/options.proto", }
var E_Index = &proto.ExtensionDesc{ ExtendedType: (*descriptor.MessageOptions)(nil), ExtensionType: ([]*IndexDescriptor)(nil), Field: 1057, Name: "michelangelo.api.index", Tag: "bytes,1057,rep,name=index", Filename: "michelangelo/api/options.proto", }
var E_NoDefault = &proto.ExtensionDesc{ ExtendedType: (*descriptor.MessageOptions)(nil), ExtensionType: (*bool)(nil), Field: 1058, Name: "michelangelo.api.no_default", Tag: "varint,1058,opt,name=no_default", Filename: "michelangelo/api/options.proto", }
var E_Optional = &proto.ExtensionDesc{ ExtendedType: (*descriptor.OneofOptions)(nil), ExtensionType: (*bool)(nil), Field: 7181, Name: "michelangelo.api.optional", Tag: "varint,7181,opt,name=optional", Filename: "michelangelo/api/options.proto", }
var E_Relationship = &proto.ExtensionDesc{ ExtendedType: (*descriptor.MessageOptions)(nil), ExtensionType: ([]*RelationshipDescriptor)(nil), Field: 1059, Name: "michelangelo.api.relationship", Tag: "bytes,1059,rep,name=relationship", Filename: "michelangelo/api/options.proto", }
var E_RenameTo = &proto.ExtensionDesc{ ExtendedType: (*descriptor.MessageOptions)(nil), ExtensionType: (*string)(nil), Field: 1060, Name: "michelangelo.api.rename_to", Tag: "bytes,1060,opt,name=rename_to", Filename: "michelangelo/api/options.proto", }
var E_Required = &proto.ExtensionDesc{ ExtendedType: (*descriptor.OneofOptions)(nil), ExtensionType: (*bool)(nil), Field: 7180, Name: "michelangelo.api.required", Tag: "varint,7180,opt,name=required", Filename: "michelangelo/api/options.proto", }
var E_Resource = &proto.ExtensionDesc{ ExtendedType: (*descriptor.MessageOptions)(nil), ExtensionType: (*ResourceDescriptor)(nil), Field: 1056, Name: "michelangelo.api.resource", Tag: "bytes,1056,opt,name=resource", Filename: "michelangelo/api/options.proto", }
var E_ResourceList = &proto.ExtensionDesc{ ExtendedType: (*descriptor.MessageOptions)(nil), ExtensionType: (*ResourceListDescriptor)(nil), Field: 1055, Name: "michelangelo.api.resource_list", Tag: "bytes,1055,opt,name=resource_list", Filename: "michelangelo/api/options.proto", }
var E_ResourceReference = &proto.ExtensionDesc{ ExtendedType: (*descriptor.FieldOptions)(nil), ExtensionType: (*ResourceReference)(nil), Field: 5771, Name: "michelangelo.api.resource_reference", Tag: "bytes,5771,opt,name=resource_reference", Filename: "michelangelo/api/options.proto", }
var E_Sensitive = &proto.ExtensionDesc{ ExtendedType: (*descriptor.FieldOptions)(nil), ExtensionType: (*bool)(nil), Field: 5773, Name: "michelangelo.api.sensitive", Tag: "varint,5773,opt,name=sensitive", Filename: "michelangelo/api/options.proto", }
var E_Validation = &proto.ExtensionDesc{ ExtendedType: (*descriptor.FieldOptions)(nil), ExtensionType: ([]*Validation)(nil), Field: 5770, Name: "michelangelo.api.validation", Tag: "bytes,5770,rep,name=validation", Filename: "michelangelo/api/options.proto", }
var LogicalOperator_name = map[int32]string{
0: "LOGICAL_OPERATOR_AND",
1: "LOGICAL_OPERATOR_OR",
}
var LogicalOperator_value = map[string]int32{
"LOGICAL_OPERATOR_AND": 0,
"LOGICAL_OPERATOR_OR": 1,
}
var SortOrder_name = map[int32]string{
0: "SORT_ORDER_INVALID",
1: "SORT_ORDER_ASC",
2: "SORT_ORDER_DESC",
}
var SortOrder_value = map[string]int32{
"SORT_ORDER_INVALID": 0,
"SORT_ORDER_ASC": 1,
"SORT_ORDER_DESC": 2,
}
Functions ¶
This section is empty.
Types ¶
type Condition ¶
type Condition struct {
Type string `protobuf:"bytes,1,opt,name=type,proto3" json:"type,omitempty"`
Status ConditionStatus `protobuf:"varint,2,opt,name=status,proto3,enum=michelangelo.api.ConditionStatus" json:"status,omitempty"`
Reason string `protobuf:"bytes,3,opt,name=reason,proto3" json:"reason,omitempty"`
Message string `protobuf:"bytes,4,opt,name=message,proto3" json:"message,omitempty"`
LastUpdatedTimestamp int64 `protobuf:"varint,5,opt,name=last_updated_timestamp,json=lastUpdatedTimestamp,proto3" json:"last_updated_timestamp,omitempty"`
Metadata *types.Any `protobuf:"bytes,6,opt,name=metadata,proto3" json:"metadata,omitempty"`
ObservedGeneration int64 `protobuf:"varint,7,opt,name=observed_generation,json=observedGeneration,proto3" json:"observed_generation,omitempty"`
}
func (*Condition) Descriptor ¶
func (*Condition) GetLastUpdatedTimestamp ¶
func (*Condition) GetMessage ¶
func (*Condition) GetMetadata ¶
func (*Condition) GetObservedGeneration ¶
func (*Condition) GetStatus ¶
func (m *Condition) GetStatus() ConditionStatus
func (*Condition) MarshalToSizedBuffer ¶
func (*Condition) ProtoMessage ¶
func (*Condition) ProtoMessage()
func (*Condition) XXX_DiscardUnknown ¶
func (m *Condition) XXX_DiscardUnknown()
func (*Condition) XXX_Marshal ¶
func (*Condition) XXX_Unmarshal ¶
type ConditionStatus ¶
type ConditionStatus int32
const ( CONDITION_STATUS_UNKNOWN ConditionStatus = 0 CONDITION_STATUS_TRUE ConditionStatus = 1 CONDITION_STATUS_FALSE ConditionStatus = 2 )
func (ConditionStatus) EnumDescriptor ¶
func (ConditionStatus) EnumDescriptor() ([]byte, []int)
func (ConditionStatus) String ¶
func (x ConditionStatus) String() string
type Criterion ¶
type Criterion struct {
FieldName string `protobuf:"bytes,1,opt,name=field_name,json=fieldName,proto3" json:"field_name,omitempty"`
MatchValue *types.Any `protobuf:"bytes,2,opt,name=match_value,json=matchValue,proto3" json:"match_value,omitempty"`
Operator CriterionOperator `protobuf:"varint,3,opt,name=operator,proto3,enum=michelangelo.api.CriterionOperator" json:"operator,omitempty"`
}
func (*Criterion) Descriptor ¶
func (*Criterion) GetFieldName ¶
func (*Criterion) GetMatchValue ¶
func (*Criterion) GetOperator ¶
func (m *Criterion) GetOperator() CriterionOperator
func (*Criterion) MarshalToSizedBuffer ¶
func (*Criterion) ProtoMessage ¶
func (*Criterion) ProtoMessage()
func (*Criterion) XXX_DiscardUnknown ¶
func (m *Criterion) XXX_DiscardUnknown()
func (*Criterion) XXX_Marshal ¶
func (*Criterion) XXX_Unmarshal ¶
type CriterionOperation ¶
type CriterionOperation struct {
Criterion []*Criterion `protobuf:"bytes,1,rep,name=criterion,proto3" json:"criterion,omitempty"`
LogicalOperator LogicalOperator `` /* 145-byte string literal not displayed */
SubOperations []*CriterionOperation `protobuf:"bytes,3,rep,name=sub_operations,json=subOperations,proto3" json:"sub_operations,omitempty"`
}
func (*CriterionOperation) Descriptor ¶
func (*CriterionOperation) Descriptor() ([]byte, []int)
func (*CriterionOperation) Equal ¶
func (this *CriterionOperation) Equal(that interface{}) bool
func (*CriterionOperation) GetCriterion ¶
func (m *CriterionOperation) GetCriterion() []*Criterion
func (*CriterionOperation) GetLogicalOperator ¶
func (m *CriterionOperation) GetLogicalOperator() LogicalOperator
func (*CriterionOperation) GetSubOperations ¶
func (m *CriterionOperation) GetSubOperations() []*CriterionOperation
func (*CriterionOperation) GoString ¶
func (this *CriterionOperation) GoString() string
func (*CriterionOperation) Marshal ¶
func (m *CriterionOperation) Marshal() (dAtA []byte, err error)
func (*CriterionOperation) MarshalTo ¶
func (m *CriterionOperation) MarshalTo(dAtA []byte) (int, error)
func (*CriterionOperation) MarshalToSizedBuffer ¶
func (m *CriterionOperation) MarshalToSizedBuffer(dAtA []byte) (int, error)
func (*CriterionOperation) ProtoMessage ¶
func (*CriterionOperation) ProtoMessage()
func (*CriterionOperation) Reset ¶
func (m *CriterionOperation) Reset()
func (*CriterionOperation) Size ¶
func (m *CriterionOperation) Size() (n int)
func (*CriterionOperation) String ¶
func (this *CriterionOperation) String() string
func (*CriterionOperation) Unmarshal ¶
func (m *CriterionOperation) Unmarshal(dAtA []byte) error
func (*CriterionOperation) XXX_DiscardUnknown ¶
func (m *CriterionOperation) XXX_DiscardUnknown()
func (*CriterionOperation) XXX_Marshal ¶
func (m *CriterionOperation) XXX_Marshal(b []byte, deterministic bool) ([]byte, error)
func (*CriterionOperation) XXX_Merge ¶
func (m *CriterionOperation) XXX_Merge(src proto.Message)
func (*CriterionOperation) XXX_Size ¶
func (m *CriterionOperation) XXX_Size() int
func (*CriterionOperation) XXX_Unmarshal ¶
func (m *CriterionOperation) XXX_Unmarshal(b []byte) error
type CriterionOperator ¶
type CriterionOperator int32
const ( CRITERION_OPERATOR_INVALID CriterionOperator = 0 CRITERION_OPERATOR_EQUAL CriterionOperator = 1 CRITERION_OPERATOR_NOT_EQUAL CriterionOperator = 2 CRITERION_OPERATOR_GREATER_THAN CriterionOperator = 3 CRITERION_OPERATOR_GREATER_THAN_OR_EQUAL_TO CriterionOperator = 4 CRITERION_OPERATOR_LESS_THAN CriterionOperator = 5 CRITERION_OPERATOR_LESS_THAN_OR_EQUAL_TO CriterionOperator = 6 CRITERION_OPERATOR_IN CriterionOperator = 7 CRITERION_OPERATOR_NOT_IN CriterionOperator = 8 CRITERION_OPERATOR_LIKE CriterionOperator = 9 CRITERION_OPERATOR_IS_NULL CriterionOperator = 10 CRITERION_OPERATOR_IS_NOT_NULL CriterionOperator = 11 )
func (CriterionOperator) EnumDescriptor ¶
func (CriterionOperator) EnumDescriptor() ([]byte, []int)
func (CriterionOperator) String ¶
func (x CriterionOperator) String() string
type GroupInfo ¶
type GroupInfo struct {
Name string `protobuf:"bytes,1,opt,name=name,proto3" json:"name,omitempty"`
Version string `protobuf:"bytes,2,opt,name=version,proto3" json:"version,omitempty"`
HubVersion string `protobuf:"bytes,3,opt,name=hub_version,json=hubVersion,proto3" json:"hub_version,omitempty"`
}
func (*GroupInfo) Descriptor ¶
func (*GroupInfo) GetHubVersion ¶
func (*GroupInfo) GetVersion ¶
func (*GroupInfo) MarshalToSizedBuffer ¶
func (*GroupInfo) ProtoMessage ¶
func (*GroupInfo) ProtoMessage()
func (*GroupInfo) XXX_DiscardUnknown ¶
func (m *GroupInfo) XXX_DiscardUnknown()
func (*GroupInfo) XXX_Marshal ¶
func (*GroupInfo) XXX_Unmarshal ¶
type IndexDescriptor ¶
type IndexDescriptor struct {
Path string `protobuf:"bytes,1,opt,name=path,proto3" json:"path,omitempty"`
Key string `protobuf:"bytes,2,opt,name=key,proto3" json:"key,omitempty"`
TypeOverride string `protobuf:"bytes,3,opt,name=type_override,json=typeOverride,proto3" json:"type_override,omitempty"`
}
func (*IndexDescriptor) Descriptor ¶
func (*IndexDescriptor) Descriptor() ([]byte, []int)
func (*IndexDescriptor) Equal ¶
func (this *IndexDescriptor) Equal(that interface{}) bool
func (*IndexDescriptor) GetKey ¶
func (m *IndexDescriptor) GetKey() string
func (*IndexDescriptor) GetPath ¶
func (m *IndexDescriptor) GetPath() string
func (*IndexDescriptor) GetTypeOverride ¶
func (m *IndexDescriptor) GetTypeOverride() string
func (*IndexDescriptor) GoString ¶
func (this *IndexDescriptor) GoString() string
func (*IndexDescriptor) Marshal ¶
func (m *IndexDescriptor) Marshal() (dAtA []byte, err error)
func (*IndexDescriptor) MarshalToSizedBuffer ¶
func (m *IndexDescriptor) MarshalToSizedBuffer(dAtA []byte) (int, error)
func (*IndexDescriptor) ProtoMessage ¶
func (*IndexDescriptor) ProtoMessage()
func (*IndexDescriptor) Reset ¶
func (m *IndexDescriptor) Reset()
func (*IndexDescriptor) Size ¶
func (m *IndexDescriptor) Size() (n int)
func (*IndexDescriptor) String ¶
func (this *IndexDescriptor) String() string
func (*IndexDescriptor) Unmarshal ¶
func (m *IndexDescriptor) Unmarshal(dAtA []byte) error
func (*IndexDescriptor) XXX_DiscardUnknown ¶
func (m *IndexDescriptor) XXX_DiscardUnknown()
func (*IndexDescriptor) XXX_Marshal ¶
func (m *IndexDescriptor) XXX_Marshal(b []byte, deterministic bool) ([]byte, error)
func (*IndexDescriptor) XXX_Merge ¶
func (m *IndexDescriptor) XXX_Merge(src proto.Message)
func (*IndexDescriptor) XXX_Size ¶
func (m *IndexDescriptor) XXX_Size() int
func (*IndexDescriptor) XXX_Unmarshal ¶
func (m *IndexDescriptor) XXX_Unmarshal(b []byte) error
type ListOptionsExt ¶
type ListOptionsExt struct {
OrderBy []*OrderBy `protobuf:"bytes,1,rep,name=order_by,json=orderBy,proto3" json:"order_by,omitempty"`
Operation *CriterionOperation `protobuf:"bytes,2,opt,name=operation,proto3" json:"operation,omitempty"`
Pagination *PaginationSpec `protobuf:"bytes,3,opt,name=pagination,proto3" json:"pagination,omitempty"`
ReturnedFieldSkipList []string `` /* 128-byte string literal not displayed */
}
func (*ListOptionsExt) Descriptor ¶
func (*ListOptionsExt) Descriptor() ([]byte, []int)
func (*ListOptionsExt) Equal ¶
func (this *ListOptionsExt) Equal(that interface{}) bool
func (*ListOptionsExt) GetOperation ¶
func (m *ListOptionsExt) GetOperation() *CriterionOperation
func (*ListOptionsExt) GetOrderBy ¶
func (m *ListOptionsExt) GetOrderBy() []*OrderBy
func (*ListOptionsExt) GetPagination ¶
func (m *ListOptionsExt) GetPagination() *PaginationSpec
func (*ListOptionsExt) GetReturnedFieldSkipList ¶
func (m *ListOptionsExt) GetReturnedFieldSkipList() []string
func (*ListOptionsExt) GoString ¶
func (this *ListOptionsExt) GoString() string
func (*ListOptionsExt) Marshal ¶
func (m *ListOptionsExt) Marshal() (dAtA []byte, err error)
func (*ListOptionsExt) MarshalToSizedBuffer ¶
func (m *ListOptionsExt) MarshalToSizedBuffer(dAtA []byte) (int, error)
func (*ListOptionsExt) ProtoMessage ¶
func (*ListOptionsExt) ProtoMessage()
func (*ListOptionsExt) Reset ¶
func (m *ListOptionsExt) Reset()
func (*ListOptionsExt) Size ¶
func (m *ListOptionsExt) Size() (n int)
func (*ListOptionsExt) String ¶
func (this *ListOptionsExt) String() string
func (*ListOptionsExt) Unmarshal ¶
func (m *ListOptionsExt) Unmarshal(dAtA []byte) error
func (*ListOptionsExt) XXX_DiscardUnknown ¶
func (m *ListOptionsExt) XXX_DiscardUnknown()
func (*ListOptionsExt) XXX_Marshal ¶
func (m *ListOptionsExt) XXX_Marshal(b []byte, deterministic bool) ([]byte, error)
func (*ListOptionsExt) XXX_Merge ¶
func (m *ListOptionsExt) XXX_Merge(src proto.Message)
func (*ListOptionsExt) XXX_Size ¶
func (m *ListOptionsExt) XXX_Size() int
func (*ListOptionsExt) XXX_Unmarshal ¶
func (m *ListOptionsExt) XXX_Unmarshal(b []byte) error
type LogicalOperator ¶
type LogicalOperator int32
const ( LOGICAL_OPERATOR_AND LogicalOperator = 0 LOGICAL_OPERATOR_OR LogicalOperator = 1 )
func (LogicalOperator) EnumDescriptor ¶
func (LogicalOperator) EnumDescriptor() ([]byte, []int)
func (LogicalOperator) String ¶
func (x LogicalOperator) String() string
type OrderBy ¶
type OrderBy struct {
Field string `protobuf:"bytes,1,opt,name=field,proto3" json:"field,omitempty"`
Dir SortOrder `protobuf:"varint,2,opt,name=dir,proto3,enum=michelangelo.api.SortOrder" json:"dir,omitempty"`
}
func (*OrderBy) Descriptor ¶
func (*OrderBy) MarshalToSizedBuffer ¶
func (*OrderBy) ProtoMessage ¶
func (*OrderBy) ProtoMessage()
func (*OrderBy) XXX_DiscardUnknown ¶
func (m *OrderBy) XXX_DiscardUnknown()
func (*OrderBy) XXX_Marshal ¶
func (*OrderBy) XXX_Unmarshal ¶
type PaginationSpec ¶
type PaginationSpec struct {
Offset int32 `protobuf:"varint,1,opt,name=offset,proto3" json:"offset,omitempty"`
Limit int32 `protobuf:"varint,2,opt,name=limit,proto3" json:"limit,omitempty"`
}
func (*PaginationSpec) Descriptor ¶
func (*PaginationSpec) Descriptor() ([]byte, []int)
func (*PaginationSpec) Equal ¶
func (this *PaginationSpec) Equal(that interface{}) bool
func (*PaginationSpec) GetLimit ¶
func (m *PaginationSpec) GetLimit() int32
func (*PaginationSpec) GetOffset ¶
func (m *PaginationSpec) GetOffset() int32
func (*PaginationSpec) GoString ¶
func (this *PaginationSpec) GoString() string
func (*PaginationSpec) Marshal ¶
func (m *PaginationSpec) Marshal() (dAtA []byte, err error)
func (*PaginationSpec) MarshalToSizedBuffer ¶
func (m *PaginationSpec) MarshalToSizedBuffer(dAtA []byte) (int, error)
func (*PaginationSpec) ProtoMessage ¶
func (*PaginationSpec) ProtoMessage()
func (*PaginationSpec) Reset ¶
func (m *PaginationSpec) Reset()
func (*PaginationSpec) Size ¶
func (m *PaginationSpec) Size() (n int)
func (*PaginationSpec) String ¶
func (this *PaginationSpec) String() string
func (*PaginationSpec) Unmarshal ¶
func (m *PaginationSpec) Unmarshal(dAtA []byte) error
func (*PaginationSpec) XXX_DiscardUnknown ¶
func (m *PaginationSpec) XXX_DiscardUnknown()
func (*PaginationSpec) XXX_Marshal ¶
func (m *PaginationSpec) XXX_Marshal(b []byte, deterministic bool) ([]byte, error)
func (*PaginationSpec) XXX_Merge ¶
func (m *PaginationSpec) XXX_Merge(src proto.Message)
func (*PaginationSpec) XXX_Size ¶
func (m *PaginationSpec) XXX_Size() int
func (*PaginationSpec) XXX_Unmarshal ¶
func (m *PaginationSpec) XXX_Unmarshal(b []byte) error
type RelationshipDescriptor ¶
type RelationshipDescriptor struct {
Path string `protobuf:"bytes,1,opt,name=path,proto3" json:"path,omitempty"`
}
func (*RelationshipDescriptor) Descriptor ¶
func (*RelationshipDescriptor) Descriptor() ([]byte, []int)
func (*RelationshipDescriptor) Equal ¶
func (this *RelationshipDescriptor) Equal(that interface{}) bool
func (*RelationshipDescriptor) GetPath ¶
func (m *RelationshipDescriptor) GetPath() string
func (*RelationshipDescriptor) GoString ¶
func (this *RelationshipDescriptor) GoString() string
func (*RelationshipDescriptor) Marshal ¶
func (m *RelationshipDescriptor) Marshal() (dAtA []byte, err error)
func (*RelationshipDescriptor) MarshalTo ¶
func (m *RelationshipDescriptor) MarshalTo(dAtA []byte) (int, error)
func (*RelationshipDescriptor) MarshalToSizedBuffer ¶
func (m *RelationshipDescriptor) MarshalToSizedBuffer(dAtA []byte) (int, error)
func (*RelationshipDescriptor) ProtoMessage ¶
func (*RelationshipDescriptor) ProtoMessage()
func (*RelationshipDescriptor) Reset ¶
func (m *RelationshipDescriptor) Reset()
func (*RelationshipDescriptor) Size ¶
func (m *RelationshipDescriptor) Size() (n int)
func (*RelationshipDescriptor) String ¶
func (this *RelationshipDescriptor) String() string
func (*RelationshipDescriptor) Unmarshal ¶
func (m *RelationshipDescriptor) Unmarshal(dAtA []byte) error
func (*RelationshipDescriptor) XXX_DiscardUnknown ¶
func (m *RelationshipDescriptor) XXX_DiscardUnknown()
func (*RelationshipDescriptor) XXX_Marshal ¶
func (m *RelationshipDescriptor) XXX_Marshal(b []byte, deterministic bool) ([]byte, error)
func (*RelationshipDescriptor) XXX_Merge ¶
func (m *RelationshipDescriptor) XXX_Merge(src proto.Message)
func (*RelationshipDescriptor) XXX_Size ¶
func (m *RelationshipDescriptor) XXX_Size() int
func (*RelationshipDescriptor) XXX_Unmarshal ¶
func (m *RelationshipDescriptor) XXX_Unmarshal(b []byte) error
type ResourceDescriptor ¶
type ResourceDescriptor struct {
Name string `protobuf:"bytes,1,opt,name=name,proto3" json:"name,omitempty"`
ShortNames []string `protobuf:"bytes,2,rep,name=short_names,json=shortNames,proto3" json:"short_names,omitempty"`
Categories []string `protobuf:"bytes,3,rep,name=categories,proto3" json:"categories,omitempty"`
Singular string `protobuf:"bytes,4,opt,name=singular,proto3" json:"singular,omitempty"`
Scope string `protobuf:"bytes,5,opt,name=scope,proto3" json:"scope,omitempty"`
Immutable bool `protobuf:"varint,101,opt,name=immutable,proto3" json:"immutable,omitempty"`
Conversion bool `protobuf:"varint,102,opt,name=conversion,proto3" json:"conversion,omitempty"`
}
func (*ResourceDescriptor) Descriptor ¶
func (*ResourceDescriptor) Descriptor() ([]byte, []int)
func (*ResourceDescriptor) Equal ¶
func (this *ResourceDescriptor) Equal(that interface{}) bool
func (*ResourceDescriptor) GetCategories ¶
func (m *ResourceDescriptor) GetCategories() []string
func (*ResourceDescriptor) GetConversion ¶
func (m *ResourceDescriptor) GetConversion() bool
func (*ResourceDescriptor) GetImmutable ¶
func (m *ResourceDescriptor) GetImmutable() bool
func (*ResourceDescriptor) GetName ¶
func (m *ResourceDescriptor) GetName() string
func (*ResourceDescriptor) GetScope ¶
func (m *ResourceDescriptor) GetScope() string
func (*ResourceDescriptor) GetShortNames ¶
func (m *ResourceDescriptor) GetShortNames() []string
func (*ResourceDescriptor) GetSingular ¶
func (m *ResourceDescriptor) GetSingular() string
func (*ResourceDescriptor) GoString ¶
func (this *ResourceDescriptor) GoString() string
func (*ResourceDescriptor) Marshal ¶
func (m *ResourceDescriptor) Marshal() (dAtA []byte, err error)
func (*ResourceDescriptor) MarshalTo ¶
func (m *ResourceDescriptor) MarshalTo(dAtA []byte) (int, error)
func (*ResourceDescriptor) MarshalToSizedBuffer ¶
func (m *ResourceDescriptor) MarshalToSizedBuffer(dAtA []byte) (int, error)
func (*ResourceDescriptor) ProtoMessage ¶
func (*ResourceDescriptor) ProtoMessage()
func (*ResourceDescriptor) Reset ¶
func (m *ResourceDescriptor) Reset()
func (*ResourceDescriptor) Size ¶
func (m *ResourceDescriptor) Size() (n int)
func (*ResourceDescriptor) String ¶
func (this *ResourceDescriptor) String() string
func (*ResourceDescriptor) Unmarshal ¶
func (m *ResourceDescriptor) Unmarshal(dAtA []byte) error
func (*ResourceDescriptor) XXX_DiscardUnknown ¶
func (m *ResourceDescriptor) XXX_DiscardUnknown()
func (*ResourceDescriptor) XXX_Marshal ¶
func (m *ResourceDescriptor) XXX_Marshal(b []byte, deterministic bool) ([]byte, error)
func (*ResourceDescriptor) XXX_Merge ¶
func (m *ResourceDescriptor) XXX_Merge(src proto.Message)
func (*ResourceDescriptor) XXX_Size ¶
func (m *ResourceDescriptor) XXX_Size() int
func (*ResourceDescriptor) XXX_Unmarshal ¶
func (m *ResourceDescriptor) XXX_Unmarshal(b []byte) error
type ResourceIdentifier ¶
type ResourceIdentifier struct {
Namespace string `protobuf:"bytes,1,opt,name=namespace,proto3" json:"namespace,omitempty"`
Name string `protobuf:"bytes,2,opt,name=name,proto3" json:"name,omitempty"`
}
func (*ResourceIdentifier) Descriptor ¶
func (*ResourceIdentifier) Descriptor() ([]byte, []int)
func (*ResourceIdentifier) Equal ¶
func (this *ResourceIdentifier) Equal(that interface{}) bool
func (*ResourceIdentifier) GetName ¶
func (m *ResourceIdentifier) GetName() string
func (*ResourceIdentifier) GetNamespace ¶
func (m *ResourceIdentifier) GetNamespace() string
func (*ResourceIdentifier) GoString ¶
func (this *ResourceIdentifier) GoString() string
func (*ResourceIdentifier) Marshal ¶
func (m *ResourceIdentifier) Marshal() (dAtA []byte, err error)
func (*ResourceIdentifier) MarshalTo ¶
func (m *ResourceIdentifier) MarshalTo(dAtA []byte) (int, error)
func (*ResourceIdentifier) MarshalToSizedBuffer ¶
func (m *ResourceIdentifier) MarshalToSizedBuffer(dAtA []byte) (int, error)
func (*ResourceIdentifier) ProtoMessage ¶
func (*ResourceIdentifier) ProtoMessage()
func (*ResourceIdentifier) Reset ¶
func (m *ResourceIdentifier) Reset()
func (*ResourceIdentifier) Size ¶
func (m *ResourceIdentifier) Size() (n int)
func (*ResourceIdentifier) String ¶
func (this *ResourceIdentifier) String() string
func (*ResourceIdentifier) Unmarshal ¶
func (m *ResourceIdentifier) Unmarshal(dAtA []byte) error
func (*ResourceIdentifier) XXX_DiscardUnknown ¶
func (m *ResourceIdentifier) XXX_DiscardUnknown()
func (*ResourceIdentifier) XXX_Marshal ¶
func (m *ResourceIdentifier) XXX_Marshal(b []byte, deterministic bool) ([]byte, error)
func (*ResourceIdentifier) XXX_Merge ¶
func (m *ResourceIdentifier) XXX_Merge(src proto.Message)
func (*ResourceIdentifier) XXX_Size ¶
func (m *ResourceIdentifier) XXX_Size() int
func (*ResourceIdentifier) XXX_Unmarshal ¶
func (m *ResourceIdentifier) XXX_Unmarshal(b []byte) error
type ResourceListDescriptor ¶
type ResourceListDescriptor struct {
}
func (*ResourceListDescriptor) Descriptor ¶
func (*ResourceListDescriptor) Descriptor() ([]byte, []int)
func (*ResourceListDescriptor) Equal ¶
func (this *ResourceListDescriptor) Equal(that interface{}) bool
func (*ResourceListDescriptor) GoString ¶
func (this *ResourceListDescriptor) GoString() string
func (*ResourceListDescriptor) Marshal ¶
func (m *ResourceListDescriptor) Marshal() (dAtA []byte, err error)
func (*ResourceListDescriptor) MarshalTo ¶
func (m *ResourceListDescriptor) MarshalTo(dAtA []byte) (int, error)
func (*ResourceListDescriptor) MarshalToSizedBuffer ¶
func (m *ResourceListDescriptor) MarshalToSizedBuffer(dAtA []byte) (int, error)
func (*ResourceListDescriptor) ProtoMessage ¶
func (*ResourceListDescriptor) ProtoMessage()
func (*ResourceListDescriptor) Reset ¶
func (m *ResourceListDescriptor) Reset()
func (*ResourceListDescriptor) Size ¶
func (m *ResourceListDescriptor) Size() (n int)
func (*ResourceListDescriptor) String ¶
func (this *ResourceListDescriptor) String() string
func (*ResourceListDescriptor) Unmarshal ¶
func (m *ResourceListDescriptor) Unmarshal(dAtA []byte) error
func (*ResourceListDescriptor) XXX_DiscardUnknown ¶
func (m *ResourceListDescriptor) XXX_DiscardUnknown()
func (*ResourceListDescriptor) XXX_Marshal ¶
func (m *ResourceListDescriptor) XXX_Marshal(b []byte, deterministic bool) ([]byte, error)
func (*ResourceListDescriptor) XXX_Merge ¶
func (m *ResourceListDescriptor) XXX_Merge(src proto.Message)
func (*ResourceListDescriptor) XXX_Size ¶
func (m *ResourceListDescriptor) XXX_Size() int
func (*ResourceListDescriptor) XXX_Unmarshal ¶
func (m *ResourceListDescriptor) XXX_Unmarshal(b []byte) error
type ResourceReference ¶
type ResourceReference struct {
Type string `protobuf:"bytes,1,opt,name=type,proto3" json:"type,omitempty"`
}
func (*ResourceReference) Descriptor ¶
func (*ResourceReference) Descriptor() ([]byte, []int)
func (*ResourceReference) Equal ¶
func (this *ResourceReference) Equal(that interface{}) bool
func (*ResourceReference) GetType ¶
func (m *ResourceReference) GetType() string
func (*ResourceReference) GoString ¶
func (this *ResourceReference) GoString() string
func (*ResourceReference) Marshal ¶
func (m *ResourceReference) Marshal() (dAtA []byte, err error)
func (*ResourceReference) MarshalTo ¶
func (m *ResourceReference) MarshalTo(dAtA []byte) (int, error)
func (*ResourceReference) MarshalToSizedBuffer ¶
func (m *ResourceReference) MarshalToSizedBuffer(dAtA []byte) (int, error)
func (*ResourceReference) ProtoMessage ¶
func (*ResourceReference) ProtoMessage()
func (*ResourceReference) Reset ¶
func (m *ResourceReference) Reset()
func (*ResourceReference) Size ¶
func (m *ResourceReference) Size() (n int)
func (*ResourceReference) String ¶
func (this *ResourceReference) String() string
func (*ResourceReference) Unmarshal ¶
func (m *ResourceReference) Unmarshal(dAtA []byte) error
func (*ResourceReference) XXX_DiscardUnknown ¶
func (m *ResourceReference) XXX_DiscardUnknown()
func (*ResourceReference) XXX_Marshal ¶
func (m *ResourceReference) XXX_Marshal(b []byte, deterministic bool) ([]byte, error)
func (*ResourceReference) XXX_Merge ¶
func (m *ResourceReference) XXX_Merge(src proto.Message)
func (*ResourceReference) XXX_Size ¶
func (m *ResourceReference) XXX_Size() int
func (*ResourceReference) XXX_Unmarshal ¶
func (m *ResourceReference) XXX_Unmarshal(b []byte) error
type TypedStruct ¶
type TypedStruct struct {
TypeUrl string `protobuf:"bytes,1,opt,name=type_url,json=typeUrl,proto3" json:"type_url,omitempty"`
Value *types.Struct `protobuf:"bytes,2,opt,name=value,proto3" json:"value,omitempty"`
}
func (*TypedStruct) Descriptor ¶
func (*TypedStruct) Descriptor() ([]byte, []int)
func (*TypedStruct) Equal ¶
func (this *TypedStruct) Equal(that interface{}) bool
func (*TypedStruct) GetTypeUrl ¶
func (m *TypedStruct) GetTypeUrl() string
func (*TypedStruct) GetValue ¶
func (m *TypedStruct) GetValue() *types.Struct
func (*TypedStruct) GoString ¶
func (this *TypedStruct) GoString() string
func (*TypedStruct) Marshal ¶
func (m *TypedStruct) Marshal() (dAtA []byte, err error)
func (*TypedStruct) MarshalToSizedBuffer ¶
func (m *TypedStruct) MarshalToSizedBuffer(dAtA []byte) (int, error)
func (*TypedStruct) ProtoMessage ¶
func (*TypedStruct) ProtoMessage()
func (*TypedStruct) Reset ¶
func (m *TypedStruct) Reset()
func (*TypedStruct) Size ¶
func (m *TypedStruct) Size() (n int)
func (*TypedStruct) String ¶
func (this *TypedStruct) String() string
func (*TypedStruct) Unmarshal ¶
func (m *TypedStruct) Unmarshal(dAtA []byte) error
func (*TypedStruct) XXX_DiscardUnknown ¶
func (m *TypedStruct) XXX_DiscardUnknown()
func (*TypedStruct) XXX_Marshal ¶
func (m *TypedStruct) XXX_Marshal(b []byte, deterministic bool) ([]byte, error)
func (*TypedStruct) XXX_Merge ¶
func (m *TypedStruct) XXX_Merge(src proto.Message)
func (*TypedStruct) XXX_Size ¶
func (m *TypedStruct) XXX_Size() int
func (*TypedStruct) XXX_Unmarshal ¶
func (m *TypedStruct) XXX_Unmarshal(b []byte) error
type Validation ¶
type Validation struct {
Min string `protobuf:"bytes,1,opt,name=min,proto3" json:"min,omitempty"`
Max string `protobuf:"bytes,2,opt,name=max,proto3" json:"max,omitempty"`
MaxItems string `protobuf:"bytes,3,opt,name=max_items,json=maxItems,proto3" json:"max_items,omitempty"`
MinItems string `protobuf:"bytes,4,opt,name=min_items,json=minItems,proto3" json:"min_items,omitempty"`
UniqueItems bool `protobuf:"varint,5,opt,name=unique_items,json=uniqueItems,proto3" json:"unique_items,omitempty"`
MaxLength string `protobuf:"bytes,6,opt,name=max_length,json=maxLength,proto3" json:"max_length,omitempty"`
MinLength string `protobuf:"bytes,7,opt,name=min_length,json=minLength,proto3" json:"min_length,omitempty"`
Pattern string `protobuf:"bytes,8,opt,name=pattern,proto3" json:"pattern,omitempty"`
NotPattern string `protobuf:"bytes,9,opt,name=not_pattern,json=notPattern,proto3" json:"not_pattern,omitempty"`
In []string `protobuf:"bytes,10,rep,name=in,proto3" json:"in,omitempty"`
NotIn []string `protobuf:"bytes,11,rep,name=not_in,json=notIn,proto3" json:"not_in,omitempty"`
// Types that are valid to be assigned to OptionalRequired:
//
// *Validation_Optional
// *Validation_Required
OptionalRequired isValidation_OptionalRequired `protobuf_oneof:"optional_required"`
ExclMax bool `protobuf:"varint,103,opt,name=excl_max,json=exclMax,proto3" json:"excl_max,omitempty"`
ExclMin bool `protobuf:"varint,104,opt,name=excl_min,json=exclMin,proto3" json:"excl_min,omitempty"`
Msg string `protobuf:"bytes,201,opt,name=msg,proto3" json:"msg,omitempty"`
Uuid bool `protobuf:"varint,301,opt,name=uuid,proto3" json:"uuid,omitempty"`
Email bool `protobuf:"varint,302,opt,name=email,proto3" json:"email,omitempty"`
Uri bool `protobuf:"varint,303,opt,name=uri,proto3" json:"uri,omitempty"`
Ipv4 bool `protobuf:"varint,304,opt,name=ipv4,proto3" json:"ipv4,omitempty"`
Ipv6 bool `protobuf:"varint,305,opt,name=ipv6,proto3" json:"ipv6,omitempty"`
Ip bool `protobuf:"varint,306,opt,name=ip,proto3" json:"ip,omitempty"`
Hostname bool `protobuf:"varint,307,opt,name=hostname,proto3" json:"hostname,omitempty"`
HostAddress bool `protobuf:"varint,308,opt,name=host_address,json=hostAddress,proto3" json:"host_address,omitempty"`
Items *Validation `protobuf:"bytes,401,opt,name=items,proto3" json:"items,omitempty"`
Keys *Validation `protobuf:"bytes,402,opt,name=keys,proto3" json:"keys,omitempty"`
Values *Validation `protobuf:"bytes,403,opt,name=values,proto3" json:"values,omitempty"`
}
func (*Validation) Descriptor ¶
func (*Validation) Descriptor() ([]byte, []int)
func (*Validation) Equal ¶
func (this *Validation) Equal(that interface{}) bool
func (*Validation) GetEmail ¶
func (m *Validation) GetEmail() bool
func (*Validation) GetExclMax ¶
func (m *Validation) GetExclMax() bool
func (*Validation) GetExclMin ¶
func (m *Validation) GetExclMin() bool
func (*Validation) GetHostAddress ¶
func (m *Validation) GetHostAddress() bool
func (*Validation) GetHostname ¶
func (m *Validation) GetHostname() bool
func (*Validation) GetIn ¶
func (m *Validation) GetIn() []string
func (*Validation) GetIp ¶
func (m *Validation) GetIp() bool
func (*Validation) GetIpv4 ¶
func (m *Validation) GetIpv4() bool
func (*Validation) GetIpv6 ¶
func (m *Validation) GetIpv6() bool
func (*Validation) GetItems ¶
func (m *Validation) GetItems() *Validation
func (*Validation) GetKeys ¶
func (m *Validation) GetKeys() *Validation
func (*Validation) GetMax ¶
func (m *Validation) GetMax() string
func (*Validation) GetMaxItems ¶
func (m *Validation) GetMaxItems() string
func (*Validation) GetMaxLength ¶
func (m *Validation) GetMaxLength() string
func (*Validation) GetMin ¶
func (m *Validation) GetMin() string
func (*Validation) GetMinItems ¶
func (m *Validation) GetMinItems() string
func (*Validation) GetMinLength ¶
func (m *Validation) GetMinLength() string
func (*Validation) GetMsg ¶
func (m *Validation) GetMsg() string
func (*Validation) GetNotIn ¶
func (m *Validation) GetNotIn() []string
func (*Validation) GetNotPattern ¶
func (m *Validation) GetNotPattern() string
func (*Validation) GetOptional ¶
func (m *Validation) GetOptional() bool
func (*Validation) GetOptionalRequired ¶
func (m *Validation) GetOptionalRequired() isValidation_OptionalRequired
func (*Validation) GetPattern ¶
func (m *Validation) GetPattern() string
func (*Validation) GetRequired ¶
func (m *Validation) GetRequired() bool
func (*Validation) GetUniqueItems ¶
func (m *Validation) GetUniqueItems() bool
func (*Validation) GetUri ¶
func (m *Validation) GetUri() bool
func (*Validation) GetUuid ¶
func (m *Validation) GetUuid() bool
func (*Validation) GetValues ¶
func (m *Validation) GetValues() *Validation
func (*Validation) GoString ¶
func (this *Validation) GoString() string
func (*Validation) Marshal ¶
func (m *Validation) Marshal() (dAtA []byte, err error)
func (*Validation) MarshalToSizedBuffer ¶
func (m *Validation) MarshalToSizedBuffer(dAtA []byte) (int, error)
func (*Validation) ProtoMessage ¶
func (*Validation) ProtoMessage()
func (*Validation) Reset ¶
func (m *Validation) Reset()
func (*Validation) Size ¶
func (m *Validation) Size() (n int)
func (*Validation) String ¶
func (this *Validation) String() string
func (*Validation) Unmarshal ¶
func (m *Validation) Unmarshal(dAtA []byte) error
func (*Validation) XXX_DiscardUnknown ¶
func (m *Validation) XXX_DiscardUnknown()
func (*Validation) XXX_Marshal ¶
func (m *Validation) XXX_Marshal(b []byte, deterministic bool) ([]byte, error)
func (*Validation) XXX_Merge ¶
func (m *Validation) XXX_Merge(src proto.Message)
func (*Validation) XXX_OneofWrappers ¶
func (*Validation) XXX_OneofWrappers() []interface{}
XXX_OneofWrappers is for the internal use of the proto package.
func (*Validation) XXX_Size ¶
func (m *Validation) XXX_Size() int
func (*Validation) XXX_Unmarshal ¶
func (m *Validation) XXX_Unmarshal(b []byte) error
type Validation_Optional ¶
type Validation_Optional struct {
Optional bool `protobuf:"varint,101,opt,name=optional,proto3,oneof" json:"optional,omitempty"`
}
func (*Validation_Optional) Equal ¶
func (this *Validation_Optional) Equal(that interface{}) bool
func (*Validation_Optional) GoString ¶
func (this *Validation_Optional) GoString() string
func (*Validation_Optional) MarshalTo ¶
func (m *Validation_Optional) MarshalTo(dAtA []byte) (int, error)
func (*Validation_Optional) MarshalToSizedBuffer ¶
func (m *Validation_Optional) MarshalToSizedBuffer(dAtA []byte) (int, error)
func (*Validation_Optional) Size ¶
func (m *Validation_Optional) Size() (n int)
func (*Validation_Optional) String ¶
func (this *Validation_Optional) String() string
type Validation_Required ¶
type Validation_Required struct {
Required bool `protobuf:"varint,102,opt,name=required,proto3,oneof" json:"required,omitempty"`
}
func (*Validation_Required) Equal ¶
func (this *Validation_Required) Equal(that interface{}) bool
func (*Validation_Required) GoString ¶
func (this *Validation_Required) GoString() string
func (*Validation_Required) MarshalTo ¶
func (m *Validation_Required) MarshalTo(dAtA []byte) (int, error)
func (*Validation_Required) MarshalToSizedBuffer ¶
func (m *Validation_Required) MarshalToSizedBuffer(dAtA []byte) (int, error)
func (*Validation_Required) Size ¶
func (m *Validation_Required) Size() (n int)
func (*Validation_Required) String ¶
func (this *Validation_Required) String() string
Click to show internal directories.
Click to hide internal directories.